pub enum ExecutionContextVariableType {
CurrentTimestamp(PrecisionTimestampTz),
CurrentTimezone(String),
CurrentDate(Date),
}Variants
CurrentTimestamp(PrecisionTimestampTz)
an execution context dependent variable containing the current timestamp in current_timezone nullability must be NULLABILITY_REQUIRED
CurrentTimezone(String)
an execution context dependent variable containing the current session timezone as a string defined by IANA timezone database (https://www.iana.org/time-zones). nullability must be NULLABILITY_REQUIRED
CurrentDate(Date)
an execution context dependent variable containing the current date nullability must be NULLABILITY_REQUIRED
Implementations
Sourceimpl ExecutionContextVariableType
impl ExecutionContextVariableType
Sourcepub fn merge(
field: &mut Option<ExecutionContextVariableType>,
tag: u32,
wire_type: WireType,
buf: &mut impl Buf,
ctx: DecodeContext,
) -> Result<(), DecodeError>
pub fn merge( field: &mut Option<ExecutionContextVariableType>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.